@@ -12,6 +12,7 @@ var npm = require("./npm.js")
   , mapToRegistry = require("./utils/map-to-registry.js")
   , cachedPackageRoot = require("./cache/cached-package-root.js")
   , createReadStream = require("graceful-fs").createReadStream
+  , npa = require("npm-package-arg")
 
 publish.usage = "npm publish <tarball>"
               + "\nnpm publish <folder>"
@@ -121,6 +122,15 @@ function publish_ (arg, data, isRetry, cachedir, cb) {
       auth     : auth
     }
 
+    // registry-frontdoor cares about the access level, which is only
+    // configurable for scoped packages
+    if (npa(data.name).scope) {
+      params.access = config.get("access")
+    }
+    else {
+      params.access = "public"
+    }
+
     registry.publish(registryBase, params, function (er) {
       if (er && er.code === "EPUBLISHCONFLICT" &&
           npm.config.get("force") && !isRetry) {
